# Weather Connect

A simple, client-side weather application built with vanilla JavaScript and Bootstrap. This app allows users to search for a location and view the current weather conditions along with a 5-day forecast.

## Features

- Search for weather by city name
- Display current weather conditions including:
  - Temperature
  - Weather description with icon
  - Feels like temperature
  - Humidity
  - Wind speed
  - Sunrise and sunset times
- 5-day weather forecast with:
  - Date
  - Weather icon and description
  - Maximum and minimum temperatures
- Modern, responsive design with animations
- Optimized for iframe embedding
- Elegant typography using Futura PT font
- Host-only features that can be conditionally displayed
- No default API calls to save costs

## Setup

1. Clone or download this repository
2. Get an API key from [OpenWeatherMap](https://openweathermap.org/api) (free tier is sufficient)
3. Open `app.js` and replace `'YOUR_API_KEY'` with your actual API key
4. Replace the Typekit CSS link in `index.html` with your own Typekit link for Futura PT
5. Open `index.html` in a web browser or host it on a web server

## Usage in an iframe

This application is designed to work within an iframe. To embed it in your website, use the following HTML:

```html
<iframe
  src="path/to/index.html"
  width="100%"
  height="500px"
  frameborder="0"></iframe>
```

### Host-Only Features

The app includes a "host-only" feature that allows certain elements (like the search form) to be hidden from regular users and only shown to hosts. There are three ways to enable host features:

1. **URL Parameter**: Add `?isHost=true` to the URL:

   ```html
   <iframe
     src="path/to/index.html?isHost=true"
     width="100%"
     height="500px"
     frameborder="0"></iframe>
   ```

2. **PostMessage API**: Send a message from the parent page to the iframe:

   ```javascript
   // To show host features
   document.querySelector("iframe").contentWindow.postMessage(
     {
       type: "setHostStatus",
       data: { isHost: true },
     },
     "*"
   );

   // To hide host features
   document.querySelector("iframe").contentWindow.postMessage(
     {
       type: "setHostStatus",
       data: { isHost: false },
     },
     "*"
   );
   ```

3. **Set Location**: You can also set the location directly from the parent page:
   ```javascript
   document.querySelector("iframe").contentWindow.postMessage(
     {
       type: "setLocation",
       data: { location: "New York" },
     },
     "*"
   );
   ```

## API Usage Considerations

- The app does not load any weather data by default to save on API costs
- Weather data is only fetched when:
  1. A user searches for a location (if they have search permission)
  2. The parent page sends a location via postMessage
- The OpenWeatherMap API has usage limits based on your subscription plan
- Consider implementing rate limiting if you expect high traffic

## Technologies Used

- Vanilla JavaScript
- Bootstrap 5
- Font Awesome icons
- Futura PT font (via Adobe Typekit)
- OpenWeatherMap API

## Notes

- The application uses the metric system (Celsius, m/s) by default
- The free tier of OpenWeatherMap API has a limit of 60 calls per minute
- Weather icons are provided by OpenWeatherMap
- The app is sized to be compact and work well in iframe environments

## License

This project is open source and available under the [MIT License](LICENSE).
